@@ -1,9 +1,9 @@
- build_stan_inputs <- function(name, response, submodels, ...){
+ build_stan_inputs <- function(name, response, submodels, log_lik, ...){
 
   model_code <- name_to_modelcode(name)
   y_data <- get_stan_data(response)
 
-  pars <- get_pars(submodels)
+  pars <- get_pars(submodels, name, log_lik)
   submodels <- unname(submodels@submodels)
   types <- sapply(submodels, function(x) x@type)
   submodel_data <- lapply(submodels, get_stan_data)
@@ -39,13 +39,18 @@ add_placeholder_priors <- function(submodel_data, types){
 
 setGeneric("get_pars", function(object, ...) standardGeneric("get_pars"))
 
-setMethod("get_pars", "ubmsSubmodelList", function(object, ...){
+setMethod("get_pars", "ubmsSubmodelList", function(object, model_name, log_lik, ...){
   #Remove placeholder submodels - we don't want to save those parameters
   submodels <- object@submodels
   submodels <- submodels[!sapply(submodels, is_placeholder)]
   submodels <- unname(submodels)
   out <- unlist(lapply(submodels, get_pars))
-  c(out, "log_lik")
+
+  if(model_name == "distsamp") log_lik <- TRUE
+  if(any(sapply(submodels, has_spatial))) log_lik <- TRUE
+
+  if(log_lik) out <- c(out, "log_lik")
+  out
 })
 
 setMethod("get_pars", "ubmsSubmodel", function(object, ...){
@@ -137,7 +142,7 @@ get_nrandom <- function(formula, data){
 
   out <- sapply(rand, function(x){
     col_nm <- as.character(x[[3]])
-    length(unique(data[[col_nm]]))
+    length(levels(as.factor(data[[col_nm]])))
   })
   as.array(out)
 }
